Provider Documentation
======================

Authentication Providers supply varying levels of information when
authentication has occurred. Some of them can also provide API access
tokens in addition to authenticating a user for sign-on.  In each provider
section, we have outlined how to use each provider as a pyramid plugin and
as a part of the velruse standalone application.

.. toctree::
   :maxdepth: 1

   providers/facebook
   providers/github
   providers/google
   providers/live
   providers/mailru
   providers/openid
   providers/twitter
   providers/vk
   providers/yahoo
   providers/yandex
